SemanticError

Enum SemanticError 

#[non_exhaustive]
pub enum SemanticError {
Show 40 variants EmptyModel, ModelHasSurroundingWhitespace, InvalidSimilarityThreshold, ZeroTopK, ZeroMaxVectors, EmptyVector { node: String, }, NonFiniteVectorValue { node: String, index: usize, }, ZeroVector { node: String, }, TooManyVectors { count: usize, maximum: usize, }, DuplicateNode { node: String, }, MissingGraphNode { node: String, }, DimensionMismatch { node: String, expected: usize, actual: usize, }, NumericOverflow, AllocationFailed, ZeroCandidatePoolMultiplier, CandidateKeyOutOfRange { key: u64, vector_count: usize, }, EmptySeoSite { node: String, }, SeoSiteHasSurroundingWhitespace { node: String, }, EmptySeoCanonical { node: String, }, SeoCanonicalHasSurroundingWhitespace { node: String, }, EmptySeoLanguage { node: String, }, SeoLanguageHasSurroundingWhitespace { node: String, }, DuplicateSeoProfile { node: String, }, MissingSeoProfile { node: String, }, SeoProfileMissingGraphNode { node: String, }, EmptyAnchorModel, AnchorModelHasSurroundingWhitespace, InvalidAnchorSimilarityThreshold, ZeroAnchorSuggestions, EmptyAnchorLocator { source: String, }, EmptyAnchorText { source: String, locator: String, }, EmptyAnchorContext { source: String, locator: String, }, AnchorTextOutsideContext { source: String, locator: String, }, AnchorTextHasSurroundingWhitespace { source: String, locator: String, field: &'static str, }, DuplicateAnchorCandidate { source: String, locator: String, }, MissingAnchorTargetVector { target: String, }, AnchorDimensionMismatch { source: String, locator: String, expected: usize, actual: usize, }, AnchorModelMismatch { expected: String, actual: String, }, MissingSemanticEdgeAttribute { attribute: &'static str, }, Graph(GraphError),
}
Validation and graph-integration failures.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyModel

The model identifier is empty.



ModelHasSurroundingWhitespace

The model identifier has leading or trailing whitespace.



InvalidSimilarityThreshold

The cosine threshold is non-finite or outside [0, 1].



ZeroTopK

Top-K must be positive.



ZeroMaxVectors

The configured vector limit must be positive.



EmptyVector

A vector has no dimensions.

Fields

node: String


NonFiniteVectorValue

A vector contains NaN or infinity.

Fields

node: String
index: usize


ZeroVector

A vector has no direction and cannot be compared with cosine similarity.

Fields

node: String


TooManyVectors

More vectors were supplied than the caller-configured safety bound.

Fields

count: usize
maximum: usize


DuplicateNode

Two vectors target the same graph node.

Fields

node: String


MissingGraphNode

A vector targets a node absent from the input graph.

Fields

node: String


DimensionMismatch

Vectors from the same model have inconsistent dimensions.

Fields

node: String
expected: usize
actual: usize


NumericOverflow

A platform-sized counter could not be represented in graph metadata.



AllocationFailed

Semantic candidate or report storage could not be reserved.



ZeroCandidatePoolMultiplier

The vector candidate-pool multiplier must be positive.



CandidateKeyOutOfRange

A candidate engine returned a key outside the current semantic input.

Fields

key: u64
vector_count: usize


EmptySeoSite

An SEO site identifier is empty.

Fields

node: String


SeoSiteHasSurroundingWhitespace

An SEO site identifier has leading or trailing whitespace.

Fields

node: String


EmptySeoCanonical

An SEO canonical identifier is empty.

Fields

node: String


SeoCanonicalHasSurroundingWhitespace

An SEO canonical identifier has leading or trailing whitespace.

Fields

node: String


EmptySeoLanguage

An SEO language identifier is empty.

Fields

node: String


SeoLanguageHasSurroundingWhitespace

An SEO language identifier has leading or trailing whitespace.

Fields

node: String


DuplicateSeoProfile

More than one SEO profile targets the same graph node.

Fields

node: String


MissingSeoProfile

A semantic vector has no corresponding SEO profile.

Fields

node: String


SeoProfileMissingGraphNode

An SEO profile targets a node absent from the graph.

Fields

node: String


EmptyAnchorModel

The anchor matcher model identifier is empty.



AnchorModelHasSurroundingWhitespace

The anchor matcher model identifier has surrounding whitespace.



InvalidAnchorSimilarityThreshold

The anchor similarity threshold is non-finite or outside [0, 1].



ZeroAnchorSuggestions

At least one anchor suggestion per link must be requested.



EmptyAnchorLocator

A candidate anchor locator is empty.

Fields

source: String


EmptyAnchorText

Candidate anchor text is empty.

Fields

source: String
locator: String


EmptyAnchorContext

Candidate anchor context is empty.

Fields

source: String
locator: String


AnchorTextOutsideContext

Candidate anchor text is not present in its supplied source context.

Fields

source: String
locator: String


AnchorTextHasSurroundingWhitespace

Candidate anchor text metadata has surrounding whitespace.

Fields

source: String
locator: String
field: &'static str


DuplicateAnchorCandidate

More than one candidate uses the same source and locator.

Fields

source: String
locator: String


MissingAnchorTargetVector

A semantic link target has no page vector for anchor matching.

Fields

target: String


AnchorDimensionMismatch

A candidate anchor vector does not match the target-vector dimension.

Fields

source: String
locator: String
expected: usize
actual: usize


AnchorModelMismatch

A semantic edge was produced by another embedding model.

Fields

expected: String
actual: String


MissingSemanticEdgeAttribute

A semantic edge is missing an attribute required for anchor matching.

Fields

attribute: &'static str


Graph(GraphError)

The underlying graph rejected a kind, identifier, provenance, or edge.